==> wp2-be-institutional-page-bs-1.0.0-20251218.180931-1-sources.jar: com/finconsgroup/itserr/marketplace/institutional_page/bs/mapper/InstitutionalPagePartialMapper.java <==
package com.finconsgroup.itserr.marketplace.institutional_page.bs.mapper;

import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.bs.dto.OutputItemDtoWorkspaceBsDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.CreateInstitutionalPageIPDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.InstitutionalPageIPDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.OutputRequestUpdateDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.UpdateInstitutionalPageIPDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.InputCreateInstitutionalPageDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.InputUpdateInstitutionalPageDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.OutputInstitutionalPageDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.OutputRequestUpdateDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.OutputWorkspaceItemDto;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;

@Mapper(config = MapperConfiguration.class)
public interface InstitutionalPagePartialMapper {
    @Mapping(target = "workspaceFolderId", ignore = true)
    @Mapping(target = "imageUrl", ignore = true)
    CreateInstitutionalPageIPDmDto toCreateInstitutionalPageDmDto(InputCreateInstitutionalPageDto dto);

    UpdateInstitutionalPageIPDmDto toUpdateInstitutionalPageDmDto(InputUpdateInstitutionalPageDto dto);

    @Mapping(target = "wpLeads", ignore = true)
    @Mapping(target = "members", ignore = true)
    @Mapping(target = "maintainer", ignore = true)
    @Mapping(target = "updateLockedBy", ignore = true)
    @Mapping(target = "lastModifiedBy", ignore = true)
    @Mapping(target = "publications", ignore = true)
    OutputInstitutionalPageDto toOutputInstitutionalPageDto(InstitutionalPageIPDmDto dto);

    OutputWorkspaceItemDto toOutputWorkspaceItemDto(OutputItemDtoWorkspaceBsDto src);

    OutputRequestUpdateDto toOutputRequestUpdateDto(OutputRequestUpdateDmDto src);

}

==> wp2-be-institutional-page-bs-1.1.0-sources.jar: com/finconsgroup/itserr/marketplace/institutional_page/bs/mapper/InstitutionalPagePartialMapper.java <==
package com.finconsgroup.itserr.marketplace.institutional_page.bs.mapper;

import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.bs.dto.OutputItemDtoWorkspaceBsDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.CreateInstitutionalPageIPDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.InstitutionalPageIPDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.ModerationStatusIPDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.OutputRequestUpdateDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.client.dm.dto.UpdateInstitutionalPageIPDmDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.InputCreateInstitutionalPageDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.InputUpdateInstitutionalPageDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.ModerationStatus;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.OutputInstitutionalPageDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.OutputRequestUpdateDto;
import com.finconsgroup.itserr.marketplace.institutional_page.bs.dto.OutputWorkspaceItemDto;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;

@Mapper(config = MapperConfiguration.class)
public interface InstitutionalPagePartialMapper {
    @Mapping(target = "workspaceFolderId", ignore = true)
    @Mapping(target = "imageUrl", ignore = true)
    CreateInstitutionalPageIPDmDto toCreateInstitutionalPageDmDto(InputCreateInstitutionalPageDto dto);

    UpdateInstitutionalPageIPDmDto toUpdateInstitutionalPageDmDto(InputUpdateInstitutionalPageDto dto);

    @Mapping(target = "wpLeads", ignore = true)
    @Mapping(target = "members", ignore = true)
    @Mapping(target = "maintainer", ignore = true)
    @Mapping(target = "updateLockedBy", ignore = true)
    @Mapping(target = "lastModifiedBy", ignore = true)
    @Mapping(target = "publications", ignore = true)
    OutputInstitutionalPageDto toOutputInstitutionalPageDto(InstitutionalPageIPDmDto dto);

    OutputWorkspaceItemDto toOutputWorkspaceItemDto(OutputItemDtoWorkspaceBsDto src);

    OutputRequestUpdateDto toOutputRequestUpdateDto(OutputRequestUpdateDmDto src);

    ModerationStatusIPDmDto toModerationStatusIPDmDto(ModerationStatus moderationStatus);
}
